==> tecfy_corev2_package-1.1.78.tar.gz: lib/views/components/general/scanner_camera.dialog.dart <==
part of tecfy_corev2_client_package;

class ScannerCameraDialog extends StatefulWidget {
  /// label string
  final String label;
  ScannerCameraDialog([this.label = 'Barcode Scanner']);
  @override
  _ScannerCameraDialogState createState() => _ScannerCameraDialogState();
}

class _ScannerCameraDialogState extends TecfyState<ScannerCameraDialog> {
  bool _isGranted = false;
  late ScannerController _scannerController;
  bool _flashOpned = false;

  @override
  void initState() {
    _initData();
    super.initState();
    SystemChrome.setPreferredOrientations([
      DeviceOrientation.portraitUp,
    ]);
  }

  Future<String> _enterBarcode() async {
    String code = '';
    return (await AppNavigator.showAppDialog(
                context,
                (c) =>
                    SimpleDialog(title: TecfyText('Enter Barcode'), children: [
                      TextField(onChanged: (v) => code = v),
                      TextButton(
                        child: TecfyText('OK'),
                        onPressed: () {
                          AppNavigator.pop(c, code);
                        },
                      )
                    ])))
            ?.toString() ??
        '';
  }

  _initData() async {
    try {
      var isGrant = await _requestPermission();
      if (isGrant) {
        _init();
      } else {
        AppNavigator.showMessage(
                context, 'We cannot get access to camera!', MessageType.error)
            .then((d) {
          _enterBarcode().then((e) async {
            await Future.delayed(Duration(microseconds: 1));
            AppNavigator.pop(context, e);
          });
        });
      }
    } catch (err) {
      AppNavigator.showMessage(
              context, 'We cannot get access to camera!', MessageType.error)
          .then((d) {
        _enterBarcode().then((e) async {
          await Future.delayed(Duration(microseconds: 1));
          AppNavigator.pop(context, e);
        });
      });
    }
  }

  @override
  void dispose() {
    super.dispose();

    _scannerController.stopCameraPreview();
    _scannerController.stopCamera();
    SystemChrome.setPreferredOrientations([
      DeviceOrientation.landscapeRight,
      DeviceOrientation.landscapeLeft,
      DeviceOrientation.portraitUp,
      DeviceOrientation.portraitDown,
    ]);
  }

  void _resultCallback(String? val) {
    if (val != null && val.isNotEmpty) {
      AppNavigator.pop(context, val);
    }
  }

  void _init() {
    _scannerController = ScannerController(scannerResult: (result) {
      _resultCallback(result);
    }, scannerViewCreated: () {
      TargetPlatform platform = Theme.of(context).platform;
      if (TargetPlatform.iOS == platform) {
        Future.delayed(Duration(seconds: 2), () {
          _scannerController.startCamera();
          _scannerController.startCameraPreview();
        });
      } else {
        _scannerController.startCamera();
        _scannerController.startCameraPreview();
      }
    });
    setState(() {});
  }

  Future<bool> _requestPermission() async {
    if (await perm.Permission.camera.request().isGranted) {
      setState(() {
        _isGranted = true;
      });
    }
    return _isGranted;
  }

  void _onFlash() {
    if (_flashOpned == false) {
      _scannerController.openFlash();
      setState(() {
        _flashOpned = true;
      });
    } else {
      _scannerController.closeFlash();
      setState(() {
        _flashOpned = false;
      });
    }
  }

  @override
  Widget build(BuildContext context) {
    return Material(
      child: Column(
        children: [
          Row(
            mainAxisAlignment: MainAxisAlignment.spaceBetween,
            children: [
              IconButton(
                  icon: Icon(Icons.flash_on_outlined),
                  iconSize: 30,
                  color: _flashOpned ? Colors.yellow : Colors.blue,
                  onPressed: _onFlash),
              TecfyText(widget.label),
              TextButton.icon(
                onPressed: () => AppNavigator.pop(context),
                icon: Icon(Icons.close),
                label: TecfyText(""),
              )
            ],
          ),
          Expanded(
            child: _isGranted
                ? PlatformAiBarcodeScannerWidget(
                    platformScannerController: _scannerController,
                    unsupportedDescription:
                        'Scanning is not supported in this device',
                  )
                : Center(child: CircularProgressIndicator()),
          ),
        ],
      ),
    );
  }
}

==> tecfy_corev2_package-1.1.117.tar.gz: lib/views/components/general/scanner_camera.dialog.dart <==
part of tecfy_corev2_client_package;

class ScannerCameraDialog extends StatefulWidget {
  /// label string
  final String label;
  ScannerCameraDialog([this.label = 'Barcode Scanner']);
  @override
  _ScannerCameraDialogState createState() => _ScannerCameraDialogState();
}

class _ScannerCameraDialogState extends TecfyState<ScannerCameraDialog> {
  bool _isGranted = false;
  // TODO: commented to solve ai_barcode package error later
  // late ScannerController _scannerController;
  bool _flashOpned = false;

  @override
  void initState() {
    _initData();
    super.initState();
    SystemChrome.setPreferredOrientations([
      DeviceOrientation.portraitUp,
    ]);
  }

  Future<String> _enterBarcode() async {
    String code = '';
    return (await AppNavigator.showAppDialog(
                context,
                (c) =>
                    SimpleDialog(title: TecfyText('Enter Barcode'), children: [
                      TextField(onChanged: (v) => code = v),
                      TextButton(
                        child: TecfyText('OK'),
                        onPressed: () {
                          AppNavigator.pop(c, code);
                        },
                      )
                    ])))
            ?.toString() ??
        '';
  }

  _initData() async {
    try {
      var isGrant = await _requestPermission();
      if (isGrant) {
        _init();
      } else {
        AppNavigator.showMessage(
                context, 'We cannot get access to camera!', MessageType.error)
            .then((d) {
          _enterBarcode().then((e) async {
            await Future.delayed(Duration(microseconds: 1));
            AppNavigator.pop(context, e);
          });
        });
      }
    } catch (err) {
      AppNavigator.showMessage(
              context, 'We cannot get access to camera!', MessageType.error)
          .then((d) {
        _enterBarcode().then((e) async {
          await Future.delayed(Duration(microseconds: 1));
          AppNavigator.pop(context, e);
        });
      });
    }
  }

  @override
  void dispose() {
    super.dispose();
    // TODO: commented to solve ai_barcode package error later
    // _scannerController.stopCameraPreview();
    // _scannerController.stopCamera();
    SystemChrome.setPreferredOrientations([
      DeviceOrientation.landscapeRight,
      DeviceOrientation.landscapeLeft,
      DeviceOrientation.portraitUp,
      DeviceOrientation.portraitDown,
    ]);
  }

  void _resultCallback(String? val) {
    if (val != null && val.isNotEmpty) {
      AppNavigator.pop(context, val);
    }
  }

  void _init() {
    // TODO: commented to solve ai_barcode package error later
    // _scannerController = ScannerController(scannerResult: (result) {
    //   _resultCallback(result);
    // }, scannerViewCreated: () {
    //   TargetPlatform platform = Theme.of(context).platform;
    //   if (TargetPlatform.iOS == platform) {
    //     Future.delayed(Duration(seconds: 2), () {
    //       _scannerController.startCamera();
    //       _scannerController.startCameraPreview();
    //     });
    //   } else {
    //     _scannerController.startCamera();
    //     _scannerController.startCameraPreview();
    //   }
    // });
    setState(() {});
  }

  Future<bool> _requestPermission() async {
    if (await perm.Permission.camera.request().isGranted) {
      setState(() {
        _isGranted = true;
      });
    }
    return _isGranted;
  }

  void _onFlash() {
    if (_flashOpned == false) {
      //TODO: commented to solve ai_barcode package error later
      // _scannerController.openFlash();
      setState(() {
        _flashOpned = true;
      });
    } else {
      // TODO: commented to solve ai_barcode package error later
      // _scannerController.closeFlash();
      setState(() {
        _flashOpned = false;
      });
    }
  }

  @override
  Widget build(BuildContext context) {
    return Material(
      child: Column(
        children: [
          Row(
            mainAxisAlignment: MainAxisAlignment.spaceBetween,
            children: [
              IconButton(
                  icon: Icon(Icons.flash_on_outlined),
                  iconSize: 30,
                  color: _flashOpned ? Colors.yellow : Colors.blue,
                  onPressed: _onFlash),
              TecfyText(widget.label),
              TextButton.icon(
                onPressed: () => AppNavigator.pop(context),
                icon: Icon(Icons.close),
                label: TecfyText(""),
              )
            ],
          ),
          Expanded(
            child:
                //TODO: commented to solve ai_barcode package error later
                // _isGranted
                // ? PlatformAiBarcodeScannerWidget(
                //     platformScannerController: _scannerController,
                //     unsupportedDescription:
                //         'Scanning is not supported in this device',
                //   )
                // :
                Center(child: CircularProgressIndicator()),
          ),
        ],
      ),
    );
  }
}
